Index: Makefile
===================================================================
--- Makefile	(revision 18480)
+++ Makefile	(working copy)
@@ -16,17 +16,6 @@
 
 MODS:=$(patsubst %.c,%.so,$(wildcard chan_*.c))
 
-ifeq (${OSARCH},OpenBSD)
-  PTLIB=-lpt_OpenBSD_x86_r
-  H323LIB=-lh323_OpenBSD_x86_r
-endif
-
-ifeq (${OSARCH},Linux)
-  PTLIB=-lpt_linux_x86_r
-  H323LIB=-lh323_linux_x86_r
-  CHANH323LIB=-ldl
-endif
-
 ifeq (${OSARCH},CYGWIN)
   CYGSOLINK=-Wl,--out-implib=lib$@.a -Wl,--export-all-symbols
   CYGSOLIB=-L.. -L. -L../res -lasterisk.dll -lres_features.so
@@ -38,17 +27,6 @@
   CFLAGS += -mtune=$(PROC) -O3 -pipe -fomit-frame-pointer -mcpu=v8
 endif
 
-ifeq (${OSARCH},FreeBSD)
-  PTLIB=-lpt_FreeBSD_x86_r
-  H323LIB=-lh323_FreeBSD_x86_r
-  CHANH323LIB=-pthread
-endif
-
-ifeq (${OSARCH},NetBSD)
-  PTLIB=-lpt_NetBSD_x86_r
-  H323LIB=-lh323_NetBSD_x86_r
-endif
-
 ifeq (${OSARCH},Darwin)
   MODS:=$(filter-out chan_oss.so,$(MODS))
 endif
@@ -66,10 +44,36 @@
   MODS:=$(filter-out chan_phone.so,$(MODS))
 endif
 
-ifeq (${WITH_SMDI},1)
-CFLAGS+=-DWITH_SMDI
+ifeq (${OSARCH},OpenBSD)
+  PTLIB=-lpt_OpenBSD_x86_r
+  H323LIB=-lh323_OpenBSD_x86_r
 endif
 
+ifeq (${OSARCH},Linux)
+  PTLIB=-lpt_linux_x86_r
+  H323LIB=-lh323_linux_x86_r
+  CHANH323LIB=-ldl
+endif
+
+ifeq (${OSARCH},FreeBSD)
+  PTLIB=-lpt_FreeBSD_x86_r
+  H323LIB=-lh323_FreeBSD_x86_r
+  CHANH323LIB=-pthread
+endif
+
+ifeq (${OSARCH},NetBSD)
+  PTLIB=-lpt_NetBSD_x86_r
+  H323LIB=-lh323_NetBSD_x86_r
+endif
+
+ifndef OPENH323DIR
+  OPENH323DIR=$(HOME)/openh323
+endif
+
+ifndef PWLIBDIR
+  PWLIBDIR=$(HOME)/pwlib
+endif
+
 ifeq ($(wildcard h323/libchanh323.a),)
   MODS:=$(filter-out chan_h323.so,$(MODS))
 endif
@@ -82,10 +86,21 @@
 
 CFLAGS+=-Wno-missing-prototypes -Wno-missing-declarations
 
+ALSA_SRC=chan_alsa.c
+
+ifneq ($(wildcard alsa-monitor.h),)
+  CFLAGS+=-DALSA_MONITOR
+  ALSA_SRC+=alsa-monitor.h
+endif
+
 ifeq ($(wildcard $(CROSS_COMPILE_TARGET)/usr/include/alsa/asoundlib.h),)
   MODS:=$(filter-out chan_alsa.so,$(MODS))
 endif
 
+ifeq (${WITH_SMDI},1)
+CFLAGS+=-DWITH_SMDI
+endif
+
 ifndef WITHOUT_PRI
 ifneq ($(wildcard $(CROSS_COMPILE_TARGET)/usr/lib/libpri.so.1 $(CROSS_COMPILE_TARGET)/usr/local/lib/libpri.so.1),)
   CFLAGS+=-DZAPATA_PRI
@@ -98,13 +113,6 @@
   ZAPR2=-lmfcr2
 endif
 
-ALSA_SRC=chan_alsa.c
-
-ifneq ($(wildcard alsa-monitor.h),)
-  CFLAGS+=-DALSA_MONITOR
-  ALSA_SRC+=alsa-monitor.h
-endif
-
 ifndef WITHOUT_ZAPTEL
 ZAPAVAIL:=$(wildcard $(CROSS_COMPILE_TARGET)/usr/include/linux/zaptel.h $(CROSS_COMPILE_TARGET)/usr/local/include/zaptel.h)
 endif
@@ -141,14 +149,6 @@
   MODS:=$(filter-out chan_nbs.so,$(MODS))
 endif
 
-ifndef OPENH323DIR
-  OPENH323DIR=$(HOME)/openh323
-endif
-
-ifndef PWLIBDIR
-  PWLIBDIR=$(HOME)/pwlib
-endif
-
 all: depend $(MODS) 
 
 clean-depend:
@@ -159,7 +159,7 @@
 	rm -f busy.h ringtone.h gentone gentone-ulaw
 
 %.so : %.o
-	$(CC) $(SOLINK) -o $@ ${CYGSOLINK} $< ${CYGSOLIB} ${LIBS}
+	$(CC) $(SOLINK) -o $@ ${CYGSOLINK} $< ${CYGSOLIB}
 
 ifneq ($(wildcard .depend),)
   include .depend
@@ -185,10 +185,13 @@
 ringtone.h: gentone
 	./gentone ringtone 440 480
 
-chan_oss.o: chan_oss.c busy.h ringtone.h
+chan_alsa.o: $(ALSA_SRC) busy.h ringtone.h
 
-chan_alsa.o: chan_alsa.c busy.h ringtone.h
+chan_alsa.so: chan_alsa.o
+	$(CC) $(SOLINK) -o $@ $< -lasound
 
+chan_oss.o: chan_oss.c busy.h ringtone.h
+
 ifeq (${OSARCH},OpenBSD)
 chan_oss.so: chan_oss.o
 	$(CC) $(SOLINK) -o $@ chan_oss.o -lossaudio
@@ -213,11 +216,6 @@
 chan_agent.so: chan_agent.o
 	$(CC) $(SOLINK) -o $@ ${CYGSOLINK} chan_agent.o ${CYGSOLIB} ${CYG_CHAN_AGENT}
 
-chan_alsa.o: $(ALSA_SRC)
-
-chan_alsa.so: chan_alsa.o
-	$(CC) $(SOLINK) -o $@ $< -lasound -lm -ldl
-
 chan_nbs.so: chan_nbs.o
 	$(CC) $(SOLINK) -o $@ $< -lnbs
 
